import hashlib
from random import choice
from .config import sault_dictionary
from zxcvbn import zxcvbn
from math import log


def hash_it(password, hash_type='sha256', saulting=False,
            static_sault='', sault_length=6, local_parameter=''):

    def hash_password(word, hashing_type):

        # hashing password
        try:
            hashed_password = hashlib.new(hashing_type)
        except ValueError:
            raise ValueError(f'unsupported hash type {hashing_type}. Try using sha256, sha384, sha512')

        hashed_password.update(word.encode())
        word = hashed_password.hexdigest()
        return word

    def sault_password(word, static, length):

        # adding sault to the password
        if not static:
            # if static_sault isn't specified, generate the sault
            sault = ''
            for _ in range(length):
                sault += choice(sault_dictionary)
            return word + sault
        else:
            # using static_sault
            sault = static
            return word + sault

    def add_local_parameter(word, parameter):

        # adding locale_parameter
        return word + parameter

    # main function to hash the password
    if saulting:
        password = sault_password(password, static_sault, sault_length)

    if local_parameter:
        password = add_local_parameter(password, local_parameter)

    password = hash_password(password, hash_type)
    return password


def check_it(password, check_type='strength', stop_chars=''):

    if check_type == 'strength':
        result = zxcvbn(password)['crack_times_seconds']['online_no_throttling_10_per_second']
        result = int(log(result, 10))

    elif check_type == 'valid':
        for c in password:
            # checking every char in password
            if c in stop_chars:
                # if stop_char in password then it is invalid
                result = False
                break
        else:
            # if there is no stop_chars in password then it is valid
            result = True
    else:
        # unknown check_type
        raise ValueError(f'unsupported check type {check_type}. Try using strength, valid.')

    return result



from distutils.core import setup
setup(
  name = 'pypasswords', 
  packages = ['pypasswords'],
  version = '0.1', 
  license='MIT', 
  description = 'Working with passwords made simple', 
  author = 'CosmoStar',                   
  author_email = 'JustCosmos@yandex.ru',
  url = 'https://github.com/CosmoSt4r/pypasswords',
  download_url = 'https://github.com/CosmoSt4r/pypasswords/archive/v_01.tar.gz',
  keywords = ['password', 'passwords', 'check', 'hash', 'simple'],
  install_requires=[
          'hashlib',
          'zxcvbn',
      ],
  classifiers=[
      
    'Development Status :: 3 - Alpha',

    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',

    'License :: OSI Approved :: MIT License',

    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)
